package ru.ulstu.extractor.mvc;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import ru.ulstu.extractor.model.Branch;
import ru.ulstu.extractor.mvc.model.FilterForm;
import ru.ulstu.extractor.mvc.model.RepoForm;
import ru.ulstu.extractor.service.FilteringService;
import ru.ulstu.extractor.service.GitRepositoryService;

import java.util.List;

@Controller
public class GitExtractorController {
    private final FilteringService filteringService;
    private final GitRepositoryService gitRepositoryService;

    public GitExtractorController(FilteringService filteringService,
                                  GitRepositoryService gitRepositoryService) {
        this.filteringService = filteringService;
        this.gitRepositoryService = gitRepositoryService;
    }

    @GetMapping("/newRepo")
    public String indexNewRepo(Model model) {
        model.addAttribute("repoForm", new RepoForm());
        return "newRepo";
    }

    @GetMapping("/filtering")
    public String filter(Model model) {
        model.addAttribute("filterForm", new FilterForm());
        return "filtering";
    }

    /*@PostMapping("/sendRepo")
    public String sendRepo(@ModelAttribute RepoForm repoForm, Model model) {
        model.addAttribute("filterForm", new FilterForm(repoForm.getRepo()));
        if (repoForm.getBranch() == null) {
            return "newRepo";
        } else {
            return "filtering";
        }
    }*/

    @PostMapping("/sendFilter")
    public String sendFilter(@ModelAttribute FilterForm filterForm, Model model) {
        if (filterForm.getFilter() == null || filterForm.getFilter().isEmpty()) {
            model.addAttribute("error", "'Строка' не должно быть пустым");
            return "filtering";
        }
//        model.addAttribute("commits", filteringService.getCommits(filterForm.getFilter(), filterForm.getFilter()));
        return "resultRepo";
    }

    @RequestMapping(value = "/newRepo", method = RequestMethod.POST, params = "send")
    public String getBranch(@ModelAttribute RepoForm repoForm, Model model) {
        try {
            gitRepositoryService.cloneOrUpdateRepo(repoForm.getRepo());
            //  model.addAttribute("branches", gitRepositoryService.getBranches(repoForm.getRepo()));
            List<Branch> list = gitRepositoryService.getBranches(repoForm.getRepo());
            model.addAttribute("branches", list);
            return "newRepo";
        } catch (Exception ex) {
            model.addAttribute("error", ex.getMessage());
            return "newRepo";
        }
    }

    @RequestMapping(value = "/newRepo", method = RequestMethod.POST, params = "next")
    public String setBranch(@ModelAttribute RepoForm repoForm, Model model) {
        model.addAttribute("filterForm", new FilterForm(repoForm.getRepo()));
        if (repoForm.getBranch() == null) {
            return "newRepo";
        } else {
            return "filtering";
        }
    }
}
